# Copyright (c) 2012 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtGui import QTreeWidget, QTreeWidgetItem

from ...model import observe
from ...plugins import PluginManager, IPluginManager, IService
from ...ui import IDisplay


class ServicesViewer(QTreeWidget):
    """ The ServicesViewer class is a widget that implements a read-only
    visualisation of all services.
    """

    def __init__(self):
        """ Initialise the viewer. """

        super(ServicesViewer, self).__init__()

        self.setHeaderLabels(["Interface", "Implementation"])

        ipluginmanager = IPluginManager(PluginManager().instance)
        self._new_services(ipluginmanager.services)
        observe('services', ipluginmanager, self._services_changed)

    def _services_changed(self, change):
        """ Invoked when the list of services changes. """

        # At the moment services can only be added.
        self._new_services(change.new)

    def _new_services(self, services):
        """ Add a list of new services. """

        for service in services:
            iservice = IService(service)

            interface_full_name = str(service.interface)

            for i in range(self.topLevelItemCount()):
                itm = self.topLevelItem(i)
                if itm.toolTip(0) == interface_full_name:
                    break
            else:
                itm = QTreeWidgetItem(self, [service.interface.__name__])
                itm.setToolTip(0, interface_full_name)

            tool_tip = str(iservice.implementation)

            idisplay = IDisplay(iservice.implementation, exception=False)
            name = '' if idisplay is None else idisplay.name
            if name == '':
                name = tool_tip

            child_itm = QTreeWidgetItem(itm, ['', name])
            child_itm.setToolTip(1, tool_tip)
