# Copyright (c) 2012 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


class StorageError(Exception):
    """ The StorageError class is an exception raised when there is an error
    accessing a particular storage location.
    """

    def __init__(self, error, location):
        """ Initialise the exception.

        :param error:
            is a string describing the error.  It is available as the *error*
            attribute.
        :param location:
            is a :class:`~dip.io.IStorageLocation` implementation where the
            error occurred.  It is available as the ``location`` attribute.
        """

        super(StorageError, self).__init__()

        self.error = error
        self.location = location

    def __str__(self):
        """ Reimplemented to return a user friendly representation. """

        # Use a similar format to IOError.
        return "{0}: '{1}'".format(self.error, self.location)


class FormatError(StorageError):
    """ The FormatError class is an exception raised when there is an error
    decoding or encoding an object at a particular storage location.
    """
