# Copyright (c) 2012 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


import os.path

from ....model import adapt, Adapter, DelegatedTo
from ....ui import IDisplay

from .filesystem_storage_location import FilesystemStorageLocation


@adapt(FilesystemStorageLocation, to=IDisplay)
class FilesystemStorageLocationIDisplayAdapter(Adapter):
    """ The FilesystemStorageLocationIDisplayAdapter adapts a
    :class:`~dip.io.storage.filesystem.FilesystemStorageLocation` to the
    :class:`~dip.ui.IDisplay` interface.
    """

    # The name.
    name = DelegatedTo('adaptee.pathname')

    @IDisplay.short_name.getter
    def short_name(self):
        """ Invoked to get the short name. """

        return os.path.basename(self.adaptee.pathname)
