# Copyright (c) 2012 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from PyQt4.QtCore import QPoint, Qt
from PyQt4.QtGui import QToolButton
from PyQt4.QtTest import QTest

from ....automate import IAutomatedTrigger
from ....model import adapt, Adapter, notify_observers
from ....ui import IToolButton

from ..editor_widget_adapter import EditorWidgetAdapter


@adapt(QToolButton, to=IToolButton)
class QToolButtonIToolButtonAdapter(EditorWidgetAdapter):
    """ An adapter to implement IToolButton for a QToolButton. """

    # The label is embedded.
    label_policy = 'embedded'

    def configure(self, properties):
        """ Configure the editor. """

        self.adaptee.clicked.connect(self._on_clicked)

        super(QToolButtonIToolButtonAdapter, self).configure(properties)

    @IToolButton.action.getter
    def action(self):
        """ The getter for the button's action. """

        return self.adaptee.defaultAction()

    @action.setter
    def action(self, value):
        """ The setter for the button's action. """

        self.adaptee.setDefaultAction(value)

    @IToolButton.value.getter
    def value(self):
        """ The getter for the editor's value. """

        # Any value will do as it is only used to pull the Trigger.
        return False

    @value.setter
    def value(self, value):
        """ The setter for the editor's value. """

        raise ValueError("cannot set the value of a QToolButton")

    def _on_clicked(self):
        """ Invoked when clicked. """

        notify_observers('value', self, True, False)


@adapt(QToolButton, to=IAutomatedTrigger)
class QToolButtonIAutomatedTriggerAdapter(Adapter):
    """ An adapter to implement IAutomatedTrigger for the widget. """

    def simulate_trigger(self, id, delay):
        """ Simulate the user pulling the trigger

        :param id:
            is the (possibly scoped) identifier of the widget.
        :param delay:
            is the delay in milliseconds between simulated events.
        """

        QTest.mouseClick(self.adaptee, Qt.LeftButton, Qt.NoModifier, QPoint(),
                delay)
