# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from ..model import isadapted

from .container_factory import ContainerFactory
from .i_editor import IEditor
from .i_form import IForm


class Form(ContainerFactory):
    """ The Form class arranges its contents as a form. """

    # If there are no explicit contents then automatically populate the form
    # with the model's attribute types.
    auto_populate = True

    # The specific interface implemented by the view.
    view_interface = IForm

    def configure_subviews(self, view, subviews):
        """ Configure a sequence of sub-views before adding them to the
        containing view.

        :param view:
            is the containing view.
        :param subviews:
            is the sequence of sub-views.
        """

        labels = []

        for field in subviews:
            label = None

            if isadapted(field, IEditor):
                ieditor = IEditor(field)

                label_policy = ieditor.label_policy

                if label_policy == 'optional':
                    ieditor.remove_label()

                if label_policy != 'embedded':
                    label = ieditor.label

            labels.append(label)

        IForm(view).labels = labels
