# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from ..model import adapt, Adapter, Bool, Instance, Interface, Model, Str

from .i_action import IAction


class IActionBinding(Interface):
    """ The IActionBinding interface defines the additional data to be bound to
    an action.
    """

    # This is set if attribute in the model is a type rather than a callable.
    attribute_is_type = Bool()

    # The name of the attribute in the model.  This is not an
    # :term:`attribute path`.
    attribute_name = Str()

    # The model containing the attribute.
    model = Instance(Model)


@adapt(IAction, to=IActionBinding)
class IActionIActionBindingAdapter(Adapter):
    """ The IActionIActionBindingAdapter adapts IAction to IActionBinding. """
