# Copyright (c) 2012 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from ..model import Bool, Enum, Str

from .editor_factory import EditorFactory
from .i_storage_location_editor import IStorageLocationEditor


class StorageLocationEditor(EditorFactory):
    """ The StorageLocationEditor class implements a storage location editor
    factory.
    """

    # The filter hints as defined by :attr:`~dip.io.IFilterHints.filter`.
    filter_hints = Str()

    # The identifier of the format.
    format = Str()

    # The mode of the editor.  'open' means an existing location will be
    # obtained.  'save' means that a location that may or may not exist will
    # be obtained.
    mode = Enum('open', 'save')

    # This is set if a value is required.
    required = Bool(False)

    # The specific interface implemented by the view.
    view_interface = IStorageLocationEditor

    def configure(self, view):
        """ Reimplemented to configure the IStorageLocationEditor specific
        attributes.

        :param view:
            is the view to configure.
        """

        istoragelocationeditor = IStorageLocationEditor(view)

        istoragelocationeditor.filter_hints = self.filter_hints
        istoragelocationeditor.format = self.format
        istoragelocationeditor.mode = self.mode
        istoragelocationeditor.required = self.required

        super(StorageLocationEditor, self).configure(view)
