# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from .i_controller import IController
from .editor_factory import EditorFactory
from .i_tool_button import IToolButton


class ToolButton(EditorFactory):
    """ The ToolButton class implements a tool button editor factory for
    trigger attributes.
    """

    # The specific interface implemented by the view.
    view_interface = IToolButton

    def create(self, model, controller, parent):
        """ Create a tool button instance.

        :param model:
            is the model.
        :param controller:
            is the controller.
        :param parent:
            is the optional parent view.
        :return:
            the tool button instance.
        """

        editor = self.object_for_interface(self.view_interface, parent)

        # If there is an action bound to the same attribute then bind to it
        # instead.
        action = IController(controller).find_action(self.bind_to)
        if action is not None:
            IToolButton(editor).action = action
        else:
            self.bind_editor(editor, model, self.bind_to, controller)

        return editor
