# Copyright (c) 2011 Riverbank Computing Limited.
#
# This file is part of dip.
#
# This file may be used under the terms of the GNU General Public License
# v2 or v3 as published by the Free Software Foundation which can be found in
# the files LICENSE-GPL2.txt and LICENSE-GPL3.txt included in this package.
# In addition, as a special exception, Riverbank gives you certain additional
# rights.  These rights are described in the Riverbank GPL Exception, which
# can be found in the file GPL-Exception.txt in this package.
#
# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.


from ..model import List

from .container_factory import ContainerFactory
from .i_wizard import IWizard
from .wizard_page import WizardPage


class Wizard(ContainerFactory):
    """ The Wizard class implements a wizard factory, i.e. it creates views
    that implement the :class:`~dip.ui.IWizard` interface.
    """

    # The contents of the view.
    contents = List(WizardPage)

    # The identifier of each widget created by the factory.
    id = 'dip.wizard'

    # The specific interface implemented by the view.
    view_interface = IWizard

    @ContainerFactory.controller_factory.default
    def controller_factory(self):
        """ Invoked to return the default controller factory. """

        from .wizard_controller import WizardController

        return WizardController
